@@ -1,5 +1,6 @@
 import datetime
 from timetils.utils import gets
+from timetils.classes import BetterDelta, BetterDate, BetterTime, BetterDatetime
 
 __version__ = "1.1.0"
 __author__ = "shahriyardx"
@@ -7,8 +8,8 @@ __author__ = "shahriyardx"
 
 class Formatter:
     def __init__(self):
-        self.__version__ = "1.1.0"
-        self.__author__ = "shahriyardx"
+        self.__version__ = __version__
+        self.__author__ = __author__
 
     def __repr__(self):
         return "<class timetils.Formatter>"
@@ -16,16 +17,17 @@ class Formatter:
     def __str__(self):
         return "<class timetils.Formatter>"
 
-    def natural_delta(self, delta: datetime.timedelta, as_dict=False):
+    def natural_delta(self, delta: datetime.timedelta, as_string=True):
         """
-		Convert a timedelta object to string.
+        Convert a timedelta object to string.
 
-		Parameters
-		- delta			A time delta object
-		- as_dict=False	Whether it should return a dictionary or a string. 
+        Parameters
+        - delta			A time delta object
+        - as_dict=False	Whether it should return a dictionary or a string.
+
+        return			String or dictionary according to as_dict kwarg
+        """
 
-		return			String or dictionary according to as_dict kwarg
-		"""
         output = ""
         days = delta.days
         seconds = delta.seconds
@@ -37,63 +39,39 @@ class Formatter:
         minute = 0
         second = 0
 
-        if days == 0 and seconds == 0:
-            if as_dict:
-                return {
-                    "years": year,
-                    "months": month,
-                    "days": day,
-                    "hours": hour,
-                    "minutes": minute,
-                    "seconds": second,
-                }
-            output = "Just now"
-            return output
-
         year, days = gets.get_year(days)
         month, day = gets.get_month(days)
         hour, seconds = gets.get_hour(seconds)
         minute, second = gets.get_minutes(seconds)
 
-        if as_dict:
-            return {
-                "years": year,
-                "months": month,
-                "days": day,
-                "hours": hour,
-                "minutes": minute,
-                "seconds": second,
-            }
-        output = f"{f'{year} years ' if year > 0 else ''}{f'{month} months ' if month > 0 else ''}{f'{day} days ' if day > 0 else ''}{f'{hour} hours ' if hour > 0 else ''}{f'{minute} minutes ' if minute > 0 else ''}{f'{second} seconds' if second > 0 else ''}"
+        time = BetterDelta(year, month, day, hour, minute, second)
 
-        output_list = [item for item in output.split(" ") if not item == ""]
+        if days == 0 and seconds == 0:
+            if not as_string:
+                return time
+            output = "Just now"
+            return output
 
-        if len(output_list) > 2:
-
-            first_part = output_list[: len(output_list) - 2]
-            last_part = [item for item in output_list if item not in first_part]
-
-            part1 = " ".join(first_part)
-            part2 = " ".join(last_part)
-
-            output = part1 + " and " + part2
+        if not as_string:
+            return time
 
+        output = time.string
         return output
 
-    def natural_date(self, date: datetime.date, as_dict=False):
+    def natural_date(self, date: datetime.date, as_string=True):
         """
-		datetime object to a human readable time
+        datetime object to a human readable time
 
-		Parameters
-		- date				A datetime.date object
-		- as_dict=False		Whether it should return a dictionary or a string. Default False
+        Parameters
+        - date				A datetime.date object
+        - as_dict=False		Whether it should return a dictionary or a string. Default False
 
-		return				string or dictionary according to as_dict kwarg
-		"""
+        return				string or dictionary according to as_dict kwarg
+        """
         if not isinstance(date, datetime.date):
             raise ValueError("date must be a object of 'datetime.date'")
 
-        date = datetime.datetime.strftime(date, "%d")
+        dates = datetime.datetime.strftime(date, "%d")
 
         day_short = datetime.datetime.strftime(date, "%a")
         day_full = datetime.datetime.strftime(date, "%A")
@@ -104,40 +82,34 @@ class Formatter:
         year_short = datetime.datetime.strftime(date, "%y")
         year_full = datetime.datetime.strftime(date, "%Y")
 
-        if as_dict:
-            return {
-                "date": date,
-                "day_short": day_short,
-                "day_full": day_full,
-                "year_short": year_short,
-                "year_full": year_full,
-                "month_short": month_short,
-                "month_full": month_full,
-                "date": date,
-            }
-
         date_part = datetime.datetime.strftime(date, "%A, %d %b %Y")
 
-        return date_part
+        better_date = BetterDate(dates, day_short, day_full, month_short, month_full, year_short, year_full, date_part)
 
-    def natural_time(self, time: datetime.time, as_dict=False, format=12):
+        if as_string:
+            return better_date.string
+
+        return better_date
+
+    def natural_time(self, time: datetime.time, as_string=True, format=12):
         """
-		datetime object to a human readable time
+        datetime object to a human readable time
 
-		Parameters
-		- time				a datetime.time object
-		- as_dict=False		Whether it should return a dictionary or a string.
-		- format=12			12/24 hour time format
+        Parameters
+        - time				a datetime.time object
+        - as_dict=False		Whether it should return a dictionary or a string.
+        - format=12			12/24 hour time format
+
+        return				string or dictionary according to as_dict kwarg
+        """
 
-		return				string or dictionary according to as_dict kwarg
-		"""
         valids = [12, 24]
 
         if format not in valids:
-            raise ValueError("for must be either 12 or 24")
+            raise ValueError("format must be either 12 or 24")
 
         if not isinstance(time, datetime.time):
-            raise NotValidObject("time must be a object of 'datetime.time'")
+            raise ValueError("time must be a object of 'datetime.time'")
 
         hour = time.hour
         minute = time.minute
@@ -156,24 +128,23 @@ class Formatter:
         if format == 24:
             data = f"{hour}:{minute}"
 
-        if as_dict and format == 12:
-            return {"hour": hour, "minute": minute, "locale": locale}
+        time = BetterTime(hour, minute, format, locale, data)
 
-        if as_dict and format == 24:
-            return {"hour": hour, "minute": minute}
+        if as_string:
+            return time.string
 
-        return data
+        return time
 
-    def natural_datetime(self, date_time: datetime.datetime, as_dict=False):
+    def natural_datetime(self, date_time: datetime.datetime, as_string=True):
         """
-		datetime object to a human readable time
+        datetime object to a human readable time
 
-		Parameters
-		- date_time			A datetime.datetime object
-		- as_dict=False		Whether it should return a dictionary or a string.
+        Parameters
+        - date_time			A datetime.datetime object
+        - as_dict=False		Whether it should return a dictionary or a string.
 
-		return				string or dictionary according to as_dict kwarg
-		"""
+        return				string or dictionary according to as_dict kwarg
+        """
         if not isinstance(date_time, datetime.datetime):
             raise ValueError("date_time must be a valid 'datetime.datetime' object")
 
@@ -192,8 +163,9 @@ class Formatter:
         minute = datetime.datetime.strftime(date_time, "%m")
         locale = datetime.datetime.strftime(date_time, "%p")
 
-        if as_dict:
-            return {
+        output = datetime.datetime.strftime(date_time, "%A, %d %b %Y at %I:%M %p")
+
+        datas = {
                 "date": date,
                 "day_short": day_short,
                 "day_full": day_full,
@@ -201,12 +173,15 @@ class Formatter:
                 "year_full": year_full,
                 "month_short": month_short,
                 "month_full": month_full,
-                "date": date,
                 "hour": hour,
                 "minute": minute,
                 "locale": locale,
+                "datetime_string": output
             }
 
-        output = datetime.datetime.strftime(date_time, "%A, %d %b %Y at %I:%M %p")
+        better_datetime = BetterDatetime(**datas)
 
-        return output
+        if as_string:
+            return better_datetime.string
+
+        return better_datetime
